class NodeState(object):
    def __init__(self,name):
        self.name = name
    def __repr__(self):
        return '<NodeState: {}>'.format(self.name)
    def __str__(self):
        return self.name
    
DEFINED     = NodeState('DEFINED')
RUNNING     = NodeState('RUNNING')
FAILED      = NodeState('FAILED')
SUCCESS     = NodeState('SUCCESS')


from setuptools import setup, find_packages

setup(
    name = 'adage',
    author = 'Lukas Heinrich',
    author_email = 'lukas.heinrich@gmail.com',
    version = '0.8.0',
    description = 'running dynamic DAG workflows',
    packages = find_packages(),
    install_requires = [
        'networkx',
        'pydot2',
        'pygraphviz',
        'pydotplus'
    ]
)
